@@ -41,7 +41,7 @@ class Config:
     :type user_agent_appid: str
     :param user_agent_appid: A value that gets included in the User-Agent
         string in the format "app/<user_agent_appid>". Allowed characters are
-        ASCII alphanumerics and ``!$%&'*+-.^_`|~``. All other characters will
+        ASCII alphanumerics and ``!#$%&'*+-.^_`|~``. All other characters will
         be replaced by a ``-``.
 
     :type connect_timeout: float or int
@@ -115,10 +115,10 @@ class Config:
 
           * ``virtual`` -- Addressing style is always virtual. The name of the
             bucket must be DNS compatible or an exception will be thrown.
-            Endpoints will be addressed as such: ``mybucket.s3.amazonaws.com``
+            Endpoints will be addressed as such: ``amzn-s3-demo-bucket.s3.amazonaws.com``
 
           * ``path`` -- Addressing style is always by path. Endpoints will be
-            addressed as such: ``s3.amazonaws.com/mybucket``
+            addressed as such: ``s3.amazonaws.com/amzn-s3-demo-bucket``
 
         * ``us_east_1_regional_endpoint`` -- Refers to what S3 endpoint to use
           when the region is configured to be us-east-1. Values must be a
@@ -176,11 +176,14 @@ class Config:
     :type inject_host_prefix: bool
     :param inject_host_prefix: Whether host prefix injection should occur.
 
-        Defaults to True.
+        Defaults to None.
 
+        The default of None is equivalent to setting to True, which enables
+        the injection of operation parameters into the prefix of the hostname.
         Setting this to False disables the injection of operation parameters
-        into the prefix of the hostname. This is useful for clients providing
-        custom endpoints that should not have their host prefix modified.
+        into the prefix of the hostname. Setting this to False is useful for
+        clients providing custom endpoints that should not have their host
+        prefix modified.
 
     :type use_dualstack_endpoint: bool
     :param use_dualstack_endpoint: Setting to True enables dualstack
@@ -234,6 +237,56 @@ class Config:
         documentation. Invalid parameters or ones that are not used by the
         specified service will be ignored.
 
+        Defaults to None.
+
+    :type request_checksum_calculation: str
+    :param request_checksum_calculation: Determines when a checksum will be
+        calculated for request payloads. Valid values are:
+
+        * ``when_supported`` -- When set, a checksum will be calculated for
+          all request payloads of operations modeled with the ``httpChecksum``
+          trait where ``requestChecksumRequired`` is ``true`` or a
+          ``requestAlgorithmMember`` is modeled.
+
+        * ``when_required`` -- When set, a checksum will only be calculated
+          for request payloads of operations modeled with the ``httpChecksum``
+          trait where ``requestChecksumRequired`` is ``true`` or where a
+          ``requestAlgorithmMember`` is modeled and supplied.
+
+        Defaults to None.
+
+    :type response_checksum_validation: str
+    :param response_checksum_validation: Determines when checksum validation
+        will be performed on response payloads. Valid values are:
+
+        * ``when_supported`` -- When set, checksum validation is performed on
+          all response payloads of operations modeled with the ``httpChecksum``
+          trait where ``responseAlgorithms`` is modeled, except when no modeled
+          checksum algorithms are supported.
+
+        * ``when_required`` -- When set, checksum validation is not performed
+          on response payloads of operations unless the checksum algorithm is
+          supported and the ``requestValidationModeMember`` member is set to ``ENABLED``.
+
+        Defaults to None.
+
+    :type account_id_endpoint_mode: str
+    :param account_id_endpoint_mode: The value used to determine the client's
+        behavior for account ID based endpoint routing. Valid values are:
+
+        * ``preferred`` - The endpoint should include account ID if available.
+        * ``disabled`` - A resolved endpoint does not include account ID.
+        * ``required`` - The endpoint must include account ID. If the account ID
+          isn't available, an exception will be raised.
+
+        If a value is not provided, the client will default to ``preferred``.
+
+        Defaults to None.
+
+    :type auth_scheme_preference: str
+    :param auth_scheme_preference: A comma-delimited string of case-sensitive
+        auth scheme names used to determine the client's auth scheme preference.
+
         Defaults to None.
     """
 
@@ -253,7 +306,7 @@ class Config:
             ('s3', None),
             ('retries', None),
             ('client_cert', None),
-            ('inject_host_prefix', True),
+            ('inject_host_prefix', None),
             ('endpoint_discovery_enabled', None),
             ('use_dualstack_endpoint', None),
             ('use_fips_endpoint', None),
@@ -264,6 +317,10 @@ class Config:
             ('disable_request_compression', None),
             ('client_context_params', None),
             ('sigv4a_signing_region_set', None),
+            ('request_checksum_calculation', None),
+            ('response_checksum_validation', None),
+            ('account_id_endpoint_mode', None),
+            ('auth_scheme_preference', None),
         ]
     )
 
@@ -271,11 +328,36 @@ class Config:
         'connect_timeout': None,
     }
 
+    # The original default value of the inject_host_prefix parameter was True.
+    # This prevented the ability to override the value from other locations in
+    # the parameter provider chain, like env vars or the shared configuration
+    # file. TO accomplish this, we need to disambiguate when the value was set
+    # by the user or not. This overrides the parameter with a property so the
+    # default value of inject_host_prefix is still True if it is not set by the
+    # user.
+    @property
+    def inject_host_prefix(self):
+        if self._inject_host_prefix == "UNSET":
+            return True
+
+        return self._inject_host_prefix
+
+    # Override the setter for the case where the user does supply a value;
+    # _inject_host_prefix will no longer be "UNSET".
+    @inject_host_prefix.setter
+    def inject_host_prefix(self, value):
+        self._inject_host_prefix = value
+
     def __init__(self, *args, **kwargs):
         self._user_provided_options = self._record_user_provided_options(
             args, kwargs
         )
 
+        # By default, we use a value that indicates the user did not
+        # set it. This value MUST persist on the Config object to be used
+        # elsewhere.
+        self._inject_host_prefix = 'UNSET'
+
         # Merge the user_provided options onto the default options
         config_vars = copy.copy(self.OPTION_DEFAULTS)
         defaults_mode = self._user_provided_options.get(
@@ -283,10 +365,20 @@ class Config:
         )
         if defaults_mode != 'legacy':
             config_vars.update(self.NON_LEGACY_OPTION_DEFAULTS)
+
         config_vars.update(self._user_provided_options)
 
         # Set the attributes based on the config_vars
         for key, value in config_vars.items():
+            # Default values for the Config object are set here. We don't want
+            # to use `setattr` in the case where the user already supplied a
+            # value.
+            if (
+                key == 'inject_host_prefix'
+                and 'inject_host_prefix'
+                not in self._user_provided_options.keys()
+            ):
+                continue
             setattr(self, key, value)
 
         # Validate the s3 options
